@@ -55,13 +55,13 @@ class Layout(object):
 
         >>> layout = Layout([(0, 1), (0, 2)])
         >>> coords = layout[1]
-        >>> print coords
+        >>> print(coords)
         [0, 2]
         >>> coords = (0, 3)
-        >>> print layout[1]
+        >>> print(layout[1])
         [0, 2]
         >>> layout[1] = coords
-        >>> print layout[1]
+        >>> print(layout[1])
         [0, 3]
     """
     
@@ -445,3 +445,4 @@ class Layout(object):
         self.scale(*ratios)
         self.translate(*translations)
 
+
